import logging

from decouple import config
from niobot import Context, NioBot, SyncResponse


DEBUG = config("DEBUG", default=False, cast=bool)

if DEBUG:
    logging.basicConfig(level=logging.DEBUG)
else:
    logging.basicConfig(level=logging.INFO)


bot = NioBot(
    homeserver=config("HOMESERVER", cast=str),
    user_id=config("USER_ID", cast=str),
    device_id=config("DEVICE_ID", default="deez-nutz", cast=str),
    store_path=config("STORE_PATH", default="./store", cast=str),
    command_prefix="!",
    case_insensitive=True,
    owner_id=config("OWNER_ID", cast=str),
)

bot.mount_module("tomservobot.chance")
bot.mount_module("tomservobot.reactions")


@bot.on_event("ready")
async def on_ready(_: SyncResponse):
    """Triggers when the bot is completely loaded."""
    print("Bot is ready!")


@bot.on_event("command_error")
async def on_command_error(_: Context, error: Exception):
    """Triggers when an error occurs in a command so we can handle it."""
    print(f"Error: {error}")


if __name__ == "__main__":
    bot.run(access_token=config("ACCESS_TOKEN", cast=str))
